
## CATO-CLI - query.accountManagement:
[Click here](https://api.catonetworks.com/documentation/#query-accountManagement) for documentation on this operation.

### Usage for query.accountManagement:

`catocli query accountManagement -h`

`catocli query accountManagement <json>`

`catocli query accountManagement "$(cat < accountManagement.json)"`

`catocli query accountManagement '{}'`

#### Operation Arguments for query.accountManagement ####
`accountId` [ID] - (required) N/A 
